/* 
 *  Author: Chris Lord <chris@openedhand.com>
 *
 *  Copyright (c) 2007 OpenedHand Ltd - http://www.openedhand.com/
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 */

#include <glib.h>
#include <libjana/jana.h>
#include <libjana-ecal/jana-ecal.h>
#include <libjana-gtk/jana-gtk.h>

static JanaStoreView *store_view = NULL;
static JanaTime *range_start, *range_end;

static void
opened_cb (JanaStore *store, JanaGtkEventStore *event_store)
{
	store_view = jana_store_get_view (store);
	jana_store_view_set_range (store_view, range_start, range_end);
	jana_gtk_event_store_set_view (event_store, store_view);

	jana_store_view_start (store_view);
}

int
main (int argc, char **argv)
{
	JanaStore *store;
	JanaDuration *duration;
	JanaGtkEventStore *event_store;
	GtkWidget *window, *week_view;
	
	gtk_init (&argc, &argv);
	
	store = jana_ecal_store_new (JANA_COMPONENT_EVENT);
	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
	event_store = jana_gtk_event_store_new ();
	
	range_start = jana_ecal_utils_time_today ("UTC");
	jana_time_set_isdate (range_start, TRUE);
	range_end = jana_time_duplicate (range_start);
	jana_time_set_day (range_end, jana_time_get_day (range_end) + 7);
	
	duration = jana_duration_new (range_start, range_end);
	jana_time_set_isdate (duration->start, FALSE);
	jana_time_set_hours (duration->start, 6);
	jana_time_set_isdate (duration->end, FALSE);
	jana_time_set_hours (duration->end, 18);

	week_view = jana_gtk_day_view_new (duration, 12);
	jana_duration_free (duration);
	g_object_set (G_OBJECT (jana_gtk_day_view_get_cell_renderer (
		JANA_GTK_DAY_VIEW (week_view))), "style-hint", "button", NULL);
	
	jana_utils_time_set_start_of_week (range_start);
	jana_utils_time_set_end_of_week (range_end);

	gtk_container_add (GTK_CONTAINER (window), week_view);
	gtk_window_set_default_size (GTK_WINDOW (window), 400, 350);
	
	g_signal_connect (G_OBJECT (window), "delete-event",
		G_CALLBACK (gtk_main_quit), NULL);
	
	gtk_widget_show_all (window);
	
	g_signal_connect (G_OBJECT (store), "opened",
		G_CALLBACK (opened_cb), event_store);

	jana_gtk_day_view_add_store (JANA_GTK_DAY_VIEW (week_view),event_store);
	jana_store_open (store);
	
	gtk_main ();
	
	g_object_unref (range_start);
	g_object_unref (range_end);
	g_object_unref (store);
	if (store_view) g_object_unref (store_view);
	
	return 0;
}

